@@ -1,7 +1,7 @@
 package Org::Document;
 
-our $DATE = '2016-07-14'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2016-10-02'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use locale;
@@ -68,6 +68,12 @@ my  $text_re       =
        #(?<plain_text>   .+?) # too dispersy
       }sxi;
 
+# XXX parser must be fixed: block elements have different precedence instead of
+# flat like this. a headline has the highest precedence and a block or a drawer
+# cannot contain a headline (e.g. "#+BEGIN_SRC foo\n* header\n#+END_SRC" should
+# not contain a literal "* header" text but that is a headline. currently, a
+# block or a drawer swallows a headline.
+
 my $block_elems_re = # top level elements
     qr/(?<block>     $ls_re (?<block_begin_indent>[ \t]*)
                      \#\+BEGIN_(?<block_name>\w+)
@@ -91,7 +97,7 @@ my $block_elems_re = # top level elements
        (?<drawer>    $ls_re [ \t]* :(?<drawer_name> \w+): [ \t]*\R
                      (?<drawer_content>(?:.|\R)*?)
                      $ls_re [ \t]* :END:) |
-       (?<text>      (?:[^#|:+*0-9\n-]+|\n|.)+?)
+       (?<text>      (?:[^#|:+*0-9\n-]+|\n+|.)+?)
        #(?<text>      .+?) # too dispersy
       /msxi;
 
@@ -175,11 +181,12 @@ sub _parse {
     $log->tracef('-> _parse(%s, pass=%d)', $str, $pass);
     my $t0 = [gettimeofday];
 
+    my $last_el;
+
     my $last_headline;
     my $last_headlines = [$self]; # [$doc, $last_hl_level1, $last_hl_lvl2, ...]
     my $last_listitem;
     my $last_lists = []; # [last_List_obj_for_indent_level0, ...]
-    my $last_el;
     my $parent;
 
     my @text;
@@ -200,9 +207,16 @@ sub _parse {
             if (@text) {
                 my $text = join("", @text);
                 if ($last_el && $last_el->isa('Org::Element::ListItem')) {
-                    # new in org-mode 7.x? the presence of text below a list
-                    # item, indented at the same level as or less than the list
-                    # item, will break the list.
+                    # a list is broken by either: a) another list (where the
+                    # bullet type or indent is different; handled in the
+                    # handling of $m{li_header}) or b) by two blank lines, or c)
+                    # by non-blank text that is indented less than or equal to
+                    # the last list item's indent.
+
+                    # a single blank line does not break a list. a text that is
+                    # more indented than the last list item's indent will become
+                    # the child of that list item.
+
                     my ($firstline, $restlines) = $text =~ /(.*?\r?\n)(.+)/s;
                     if ($restlines) {
                         $restlines =~ /\A([ \t]*)/;
@@ -387,7 +401,7 @@ sub _parse {
                 $el->is_done($state ~~ @{ $self->done_states } ? 1:0);
             }
 
-            # recognize priority
+            # recognize priority cookie
             my $prio_re = "(?:".
                 join("|", map {quotemeta} @{$self->priorities}) . ")";
             if ($title =~ s/\[#($prio_re)\]\s*//) {
@@ -654,6 +668,7 @@ sub _apply_markup {
         #             $has_text, $has_unmarkable, $newlines, $valid
         #         );
         if ($valid) {
+            no warnings 'once';
             my $mu_el = Org::Element::Text->new(
                 document => $self, parent => $parent,
                 style=>$Org::Element::Text::mu2style{$mu}, text=>'',
@@ -787,7 +802,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.49 of Org::Document (from Perl distribution Org-Parser), released on 2016-07-14.
+This document describes version 0.50 of Org::Document (from Perl distribution Org-Parser), released on 2016-10-02.
 
 =head1 SYNOPSIS
 
@@ -878,7 +893,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
+Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
 
 =head1 BUGS
 
