@@ -1,7 +1,7 @@
 package Org::Parser;
 
-our $DATE = '2016-07-14'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2016-10-02'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010001;
 use Moo;
@@ -66,8 +66,14 @@ sub parse_file {
         require Storable;
         $cache = !!((-e $cf) && (-M $cf) <= (-M $filename));
         if ($cache) {
-            $doc = Storable::retrieve($cf);
-            $doc->load_element_modules unless $loaded++;
+            eval {
+                $doc = Storable::retrieve($cf);
+                $doc->load_element_modules unless $loaded++;
+            };
+            if ($@) {
+                warn "Failed retrieving document from cache: $@, reparsing ...";
+                $cache = 0;
+            }
         }
     }
 
@@ -98,7 +104,7 @@ Org::Parser - Parse Org documents
 
 =head1 VERSION
 
-This document describes version 0.49 of Org::Parser (from Perl distribution Org-Parser), released on 2016-07-14.
+This document describes version 0.50 of Org::Parser (from Perl distribution Org-Parser), released on 2016-10-02.
 
 =head1 SYNOPSIS
 
@@ -251,7 +257,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
+Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
 
 =head1 BUGS
 
